==> groovy-sandbox-1.6-sources.jar: org/kohsuke/groovy/sandbox/SandboxTransformer.java <==
package org.kohsuke.groovy.sandbox;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SandboxTransformer
  extends org.codehaus.groovy.control.customizers.CompilationCustomizer  implements
    groovy.lang.GroovyObject {
public SandboxTransformer
() {
super ((org.codehaus.groovy.control.CompilePhase)null);
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  boolean getInterceptMethodCall() { return false;}
public  boolean isInterceptMethodCall() { return false;}
public  void setInterceptMethodCall(boolean value) { }
public  boolean getInterceptConstructor() { return false;}
public  boolean isInterceptConstructor() { return false;}
public  void setInterceptConstructor(boolean value) { }
public  boolean getInterceptProperty() { return false;}
public  boolean isInterceptProperty() { return false;}
public  void setInterceptProperty(boolean value) { }
public  boolean getInterceptArray() { return false;}
public  boolean isInterceptArray() { return false;}
public  void setInterceptArray(boolean value) { }
public  boolean getInterceptAttribute() { return false;}
public  boolean isInterceptAttribute() { return false;}
public  void setInterceptAttribute(boolean value) { }
public static final  java.lang.Object getCheckerClass() { return null;}
public static final  java.lang.Object getScriptBytecodeAdapterClass() { return null;}
public static final  org.codehaus.groovy.ast.expr.Expression getCLOSURE_THIS() { return (org.codehaus.groovy.ast.expr.Expression)null;}
@java.lang.Override() public  void call(org.codehaus.groovy.control.SourceUnit source, org.codehaus.groovy.classgen.GeneratorContext context, org.codehaus.groovy.ast.ClassNode classNode) { }
public class VisitorImpl
  extends org.kohsuke.groovy.sandbox.ScopeTrackingClassCodeExpressionTransformer  implements
    groovy.lang.GroovyObject {
public VisitorImpl
(org.codehaus.groovy.control.SourceUnit sourceUnit) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  org.codehaus.groovy.ast.expr.Expression transformArguments(org.codehaus.groovy.ast.expr.Expression e) { return (org.codehaus.groovy.ast.expr.Expression)null;}
public  org.codehaus.groovy.ast.expr.Expression makeCheckedCall(java.lang.String name, java.util.Collection<org.codehaus.groovy.ast.expr.Expression> arguments) { return (org.codehaus.groovy.ast.expr.Expression)null;}
@java.lang.Override() public  org.codehaus.groovy.ast.expr.Expression transform(org.codehaus.groovy.ast.expr.Expression exp) { return (org.codehaus.groovy.ast.expr.Expression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression boolExp(boolean v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression intExp(int v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
public  org.codehaus.groovy.ast.expr.ClassExpression classExp(org.codehaus.groovy.ast.ClassNode c) { return (org.codehaus.groovy.ast.expr.ClassExpression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression stringExp(java.lang.String v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
@java.lang.Override() protected  org.codehaus.groovy.control.SourceUnit getSourceUnit() { return (org.codehaus.groovy.control.SourceUnit)null;}
}
}

==> groovy-sandbox-1.7-sources.jar: org/kohsuke/groovy/sandbox/SandboxTransformer.java <==
package org.kohsuke.groovy.sandbox;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SandboxTransformer
  extends org.codehaus.groovy.control.customizers.CompilationCustomizer  implements
    groovy.lang.GroovyObject {
public SandboxTransformer
() {
super ((org.codehaus.groovy.control.CompilePhase)null);
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  boolean getInterceptMethodCall() { return false;}
public  boolean isInterceptMethodCall() { return false;}
public  void setInterceptMethodCall(boolean value) { }
public  boolean getInterceptConstructor() { return false;}
public  boolean isInterceptConstructor() { return false;}
public  void setInterceptConstructor(boolean value) { }
public  boolean getInterceptProperty() { return false;}
public  boolean isInterceptProperty() { return false;}
public  void setInterceptProperty(boolean value) { }
public  boolean getInterceptArray() { return false;}
public  boolean isInterceptArray() { return false;}
public  void setInterceptArray(boolean value) { }
public  boolean getInterceptAttribute() { return false;}
public  boolean isInterceptAttribute() { return false;}
public  void setInterceptAttribute(boolean value) { }
public static final  java.lang.Object getCheckerClass() { return null;}
public static final  java.lang.Object getScriptBytecodeAdapterClass() { return null;}
public static final  org.codehaus.groovy.ast.expr.Expression getCLOSURE_THIS() { return (org.codehaus.groovy.ast.expr.Expression)null;}
@java.lang.Override() public  void call(org.codehaus.groovy.control.SourceUnit source, org.codehaus.groovy.classgen.GeneratorContext context, org.codehaus.groovy.ast.ClassNode classNode) { }
public  org.codehaus.groovy.ast.ClassCodeExpressionTransformer createVisitor(org.codehaus.groovy.control.SourceUnit source) { return (org.codehaus.groovy.ast.ClassCodeExpressionTransformer)null;}
public class VisitorImpl
  extends org.kohsuke.groovy.sandbox.ScopeTrackingClassCodeExpressionTransformer {
public VisitorImpl
(org.codehaus.groovy.control.SourceUnit sourceUnit) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  org.codehaus.groovy.ast.expr.Expression transformArguments(org.codehaus.groovy.ast.expr.Expression e) { return (org.codehaus.groovy.ast.expr.Expression)null;}
public  org.codehaus.groovy.ast.expr.Expression makeCheckedCall(java.lang.String name, java.util.Collection<org.codehaus.groovy.ast.expr.Expression> arguments) { return (org.codehaus.groovy.ast.expr.Expression)null;}
@java.lang.Override() public  org.codehaus.groovy.ast.expr.Expression transform(org.codehaus.groovy.ast.expr.Expression exp) { return (org.codehaus.groovy.ast.expr.Expression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression boolExp(boolean v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression intExp(int v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
public  org.codehaus.groovy.ast.expr.ClassExpression classExp(org.codehaus.groovy.ast.ClassNode c) { return (org.codehaus.groovy.ast.expr.ClassExpression)null;}
public  org.codehaus.groovy.ast.expr.ConstantExpression stringExp(java.lang.String v) { return (org.codehaus.groovy.ast.expr.ConstantExpression)null;}
@java.lang.Override() protected  org.codehaus.groovy.control.SourceUnit getSourceUnit() { return (org.codehaus.groovy.control.SourceUnit)null;}
}
}
